@@ -10,6 +10,7 @@ import queue
 
 from communication.send_result import SendResult
 from define import *
+import main_paras
 
 
 
@@ -44,7 +45,7 @@ class WebApi(threading.Thread):
           "city": self.address[1],
           "country": self.address[2],
           "timestamp": str(self.timeStamp)+'000',
-          "mode": "speed",
+          "mode": main_paras.getTestMode(),
           "localdate": time.strftime("%d/%m/%Y",time.localtime(self.timeStamp)),
           "localtime": time.strftime("%H:%M:%S",time.localtime(self.timeStamp)),
           "readerserial": SERIAL_NO
